@@ -2,7 +2,7 @@
 Module mplutil
 ==============
 
-.. author:: Hans Terlouw <gipsy@astro.rug.nl>
+.. sectionauthor:: Hans Terlouw <gipsy@astro.rug.nl>
 .. highlight:: python
    :linenothreshold: 5
 
@@ -73,10 +73,19 @@ By default, the Qt4Agg backend does not report resize events. This work-around
 takes care of this.
  
 """
+# VOG: Next lines are only to confirm the backend
+#from sys import stdout
+#from matplotlib import rcParams
+#backend = rcParams['backend'].upper()
+#print("Backend mplutil:", backend)
+#stdout.flush()
+
 
 # Work-around for the qt4 backend which does not support the PageUp
 # and PageDown keys.
-#
+# VOG: For current versions of PyQt/Matplotlib this is not needed and 
+# it causes crashes also.
+"""
 try:
    from PyQt4 import QtCore
    from matplotlib.backends.backend_qt4 import FigureCanvasQT
@@ -94,6 +103,7 @@ except:
 
 # Work-arounds for the qt4agg backend.
 #
+
 try:
    from matplotlib.backends import backend_qt4agg
 
@@ -125,6 +135,8 @@ try:
    backend_qt4agg.FigureCanvasQTAgg._get_key = _get_key
 except:
    pass
+"""
+
 
 import weakref
    
@@ -309,14 +321,19 @@ first :class:`AxesCallback` object `draw` as an attribute.
             if axes is None:
                callback.deschedule()
                continue
-            if event.canvas is callback.canvas   and \
-                  event.name==callback.eventtype and \
-                  axes.contains(event)[0]:
-               callback.event = event
-               callback.xdata, callback.ydata = \
-                  axes.transData.inverted().transform((event.x, event.y))
-               if callback.proc(callback):
-                  break
+            try:  # VOG: Added on 15-11-2017 
+                  # because pressing a key outside the MPL canvas could still 
+                  # generate an event. This reults in TypeError: a float is required
+               if event.canvas is callback.canvas   and \
+                     event.name==callback.eventtype and \
+                     axes.contains(event)[0]:
+                  callback.event = event
+                  callback.xdata, callback.ydata = \
+                     axes.transData.inverted().transform((event.x, event.y))
+                  if callback.proc(callback):
+                     break
+            except:
+               pass
       return __handler
    __handler = staticmethod(__handler)
 
@@ -773,7 +790,7 @@ A TimeCallback object will not be deleted as long as it
 is scheduled ("active"), so it is not always necessary to keep a reference
 to it.
 This class is backend-dependent. Currently supported backends are GTKAgg,
-GTK, Qt4Agg and TkAgg.
+GTK, Qt4Agg, Qt5Agg and TkAgg.
 
 :param proc:
    the function to be called upon receiving an event of the specified
@@ -962,6 +979,54 @@ try:
 except:
    pass
 
+
+# Qt5Agg:
+#
+try:
+   from PyQt5.QtCore import QTimer
+   
+   class TimeCallback_QT5(TimeCallback):
+       
+      def __init__(self, proc, interval, schedule=True, **attr):
+         self.proc     = proc
+         self.interval = interval
+         for name in list(attr.keys()):
+            self.__dict__[name] = attr[name]
+         self.active   = False
+         self.timer = QTimer()
+         #QtCore.QObject.connect(self.timer, QtCore.SIGNAL("timeout()"),
+         #                       self.reached)
+         self.timer.timeout.connect(self.reached)
+         if schedule: self.schedule()
+
+      def schedule(self):
+         if self.active:
+            return
+         self.set_interval(self.interval)
+         self.timer.start()
+         self.active = True
+         self.scheduled.append(self)
+      
+      def deschedule(self):
+         if not self.active:
+            return
+         self.timer.stop()
+         self.active = False
+         self.scheduled.remove(self)
+
+      def set_interval(self, interval):
+         self.interval = interval
+         milliseconds = max(1,int(round(self.interval*1000.0)))
+         self.timer.setInterval(milliseconds)
+         
+      def reached(self):
+         self.proc(self)
+
+   TimeCallback.supported['QT5AGG'] = TimeCallback_QT5
+except:
+   pass
+
+
 # TkAgg:
 #
 try:
@@ -1032,8 +1097,10 @@ Here is an example::
    backend = rcParams['backend'].upper()
    if backend in ['GTK', 'GTKAGG']:
       gipsy.gtkconnect()
-   elif backend in ['QT4AGG']:
+   elif backend in ['QT4AGG', 'QT5AGG']:
       gipsy.qtconnect()
+      #gipsy.anyout("qtconnect")
+      #gipsy.anyout(backend)
    elif backend in ['TKAGG']:
       import tkinter
       def _tkio(fd, mask):
