@@ -97,7 +97,7 @@ class Ruler(object):
    or in world coordinates. The start and end point
    can also be positions entered as a string which
    follows the syntax described in method
-   :func:`positions.str2pos`. The ruler can also
+   :func:`kapteyn.positions.str2pos`. The ruler can also
    be given as a start point and a size and angle.
    These are distance and angle on a sphere.
 
