@@ -104,7 +104,7 @@ def button_setcolor(btnobj, c):
    """
    btnobj.color = c
    btnobj._lastcolor = c
-   btnobj.ax.set_axis_bgcolor(c)
+   btnobj.ax.set_facecolor(c)
    if btnobj.drawon:
       btnobj.ax.figure.canvas.draw()
 Button.setcolor = button_setcolor        # Global
@@ -636,7 +636,7 @@ class Ellipse(Poly):
       # x = asarray(x); y = asarray(y)
       # Assume symmetry and estimate ellipse parameters.
       # The indices are based on a sampling of len(xy) samples.
-      n90 = len(xy)/4
+      n90 = len(xy)//4
       self.maj = Sqrt((x[0]-self.x0)**2 +(y[0]-self.y0)**2)
       self.min = Sqrt((x[n90]-self.x0)**2 +(y[n90]-self.y0)**2)
       self.pa = degrees(Atan2(y[0]-self.y0, x[0]-self.x0))
@@ -916,7 +916,7 @@ class Shapecollection(object):
    :Notes:
 
       All shapes are derived from a polygon class. There is one method
-      that generates coordinates for all shapes and :meth:`maputils.getflux`
+      that generates coordinates for all shapes and :meth:`kapteyn.maputils.getflux`
       uses the same routine to calculate whether a pixel in an enclosing
       box is within or outside the shape. For circles and ellipses the
       number of polygon points is 360 and this slows down the calculation
@@ -1059,7 +1059,7 @@ class Shapecollection(object):
       ifigure.text(0.5,0.01, helptxt, tdict)
       
       """
-      print helptxt
+      print(helptxt)
       stdout.flush()
       """
 
@@ -1730,7 +1730,7 @@ class Shapecollection(object):
       thisline = event.artist
       #xdata, ydata = thisline.get_data()
       #ind = event.ind
-      print 'on pick line:', thisline
+      print('on pick line:', thisline)
    """ 
 
    def button_press(self, event):
