@@ -15,13 +15,12 @@
 # Kapteyn Astronomical Institute
 # Groningen, The Netherlands
 #----------------------------------------------------------------------
-
 """
 ================
 Module tabarray
 ================
 
-.. author:: Hans Terlouw <gipsy@astro.rug.nl>
+.. sectionauthor:: Hans Terlouw <gipsy@astro.rug.nl>
 
 .. highlight:: python
    :linenothreshold: 5
@@ -48,9 +47,13 @@ Functions
 .. autofunction:: writeColumns
 """
 
-import numpy, string, operator
+import numpy, string
+from collections.abc import Sequence
 from kapteyn.ascarray import ascarray
 
+def isSequenceType(obj):
+        return isinstance(obj, Sequence)
+
 class tabarray(numpy.ndarray):
 
    """
@@ -221,10 +224,10 @@ Write the contents of a tabarray to a file.
       f = open(filename, 'w')
       for line in comment:
          f.write('# %s \n' % line)
-      columns = range(arrout.ncols)
+      columns = list(range(arrout.ncols))
       if not format:
          format = ['%10g ']*arrout.ncols
-      for line in xrange(arrout.nrows):
+      for line in range(arrout.nrows):
          outline = ' '
          for column in columns:
             outline += format[column] % arrout[line, column]
@@ -278,7 +281,7 @@ TableIO-compatible function for directly extracting table data from a file.
 """
    if cols=='all':
       cols = None
-   if cols is not None and not operator.isSequenceType(cols):
+   if cols is not None and not isSequenceType(cols):
       cols = [cols]
    return tabarray(filename, comment, sepchar=sepchar, lines=lines, bad=bad
                   )[slice(*rowslice),slice(*colslice)].rows(rows).columns(cols)
